==> stagesepx-0.7.3.tar.gz: stagesepx-0.7.3/stagesepx/__init__.py <==

#  ________  _________  ________  ________  _______   ________  _______   ________        ___    ___
# |\   ____\|\___   ___\\   __  \|\   ____\|\  ___ \ |\   ____\|\  ___ \ |\   __  \      |\  \  /  /|
# \ \  \___|\|___ \  \_\ \  \|\  \ \  \___|\ \   __/|\ \  \___|\ \   __/|\ \  \|\  \     \ \  \/  / /
#  \ \_____  \   \ \  \ \ \   __  \ \  \  __\ \  \_|/_\ \_____  \ \  \_|/_\ \   ____\     \ \    / /
#   \|____|\  \   \ \  \ \ \  \ \  \ \  \|\  \ \  \_|\ \|____|\  \ \  \_|\ \ \  \___|      /     \/
#     ____\_\  \   \ \__\ \ \__\ \__\ \_______\ \_______\____\_\  \ \_______\ \__\        /  /\   \
#    |\_________\   \|__|  \|__|\|__|\|_______|\|_______|\_________\|_______|\|__|       /__/ /\ __\
#    \|_________|                                       \|_________|                     |__|/ \|__|
#

"""
MIT License

Copyright (c) 2019 williamfzc

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

__author__ = r'williamfzc'
__author_email__ = 'fengzc@vip.qq.com'
__license__ = r'MIT'
__url__ = r'https://github.com/williamfzc/stagesepx'

==> stagesepx-0.7.4.tar.gz: stagesepx-0.7.4/stagesepx/__init__.py <==

#  ________  _________  ________  ________  _______   ________  _______   ________        ___    ___
# |\   ____\|\___   ___\\   __  \|\   ____\|\  ___ \ |\   ____\|\  ___ \ |\   __  \      |\  \  /  /|
# \ \  \___|\|___ \  \_\ \  \|\  \ \  \___|\ \   __/|\ \  \___|\ \   __/|\ \  \|\  \     \ \  \/  / /
#  \ \_____  \   \ \  \ \ \   __  \ \  \  __\ \  \_|/_\ \_____  \ \  \_|/_\ \   ____\     \ \    / /
#   \|____|\  \   \ \  \ \ \  \ \  \ \  \|\  \ \  \_|\ \|____|\  \ \  \_|\ \ \  \___|      /     \/
#     ____\_\  \   \ \__\ \ \__\ \__\ \_______\ \_______\____\_\  \ \_______\ \__\        /  /\   \
#    |\_________\   \|__|  \|__|\|__|\|_______|\|_______|\_________\|_______|\|__|       /__/ /\ __\
#    \|_________|                                       \|_________|                     |__|/ \|__|
#

"""
MIT License

Copyright (c) 2019 williamfzc

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

__PROJECT_NAME__ = r'stagesepx'
__AUTHOR__ = r'williamfzc'
__AUTHOR_EMAIL__ = r'fengzc@vip.qq.com'
__LICENSE__ = r'MIT'
__URL__ = r'https://github.com/williamfzc/stagesepx'
__VERSION__ = r'0.7.4'
__DESCRIPTION__ = r'detect stages in video automatically'
